swytcher package
================

Submodules
----------

swytcher\.cli module
--------------------

.. automodule:: swytcher.cli
    :members:
    :undoc-members:
    :show-inheritance:

swytcher\.settings module
-------------------------

.. automodule:: swytcher.settings
    :members:
    :undoc-members:
    :show-inheritance:

swytcher\.swytcher module
-------------------------

.. automodule:: swytcher.swytcher
    :members:
    :undoc-members:
    :show-inheritance:

swytcher\.util module
---------------------

.. automodule:: swytcher.util
    :members:
    :undoc-members:
    :show-inheritance:

swytcher\.xwindow module
------------------------

.. automodule:: swytcher.xwindow
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: swytcher
    :members:
    :undoc-members:
    :show-inheritance:
